==> haskell-shelly-1.11.0-74.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shelly
version:              1.11.0
visibility:           public
id:                   shelly-1.11.0-JmDpUTnbS08F8He1azDhqI
key:                  shelly-1.11.0-JmDpUTnbS08F8He1azDhqI
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/gregwebs/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/gregwebs/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  8522e5429ca8ad113d068429ee4c5460
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.6.6/site-local/shelly-1.11.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shelly-1.11.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shelly-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.11.0-JmDpUTnbS08F8He1azDhqI
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    enclosed-exceptions-1.0.3-IH7IgGKTEJFJLmctIAPJiT exceptions-0.10.7
    filepath-1.4.300.1 lifted-async-0.11.0-LshGdlAzxQp43RtlU7idG
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    process-1.6.19.0 text-2.0.2 time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.11.0-75-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shelly
version:              1.11.0
visibility:           public
id:                   shelly-1.11.0-ILDqiDnnfQU5ZecPvyA3FE
key:                  shelly-1.11.0-ILDqiDnnfQU5ZecPvyA3FE
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/gregwebs/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/gregwebs/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  4c6547a3d4006840718a691e9a269ef3
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.6.6/site-local/shelly-1.11.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shelly-1.11.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shelly-1.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.11.0-ILDqiDnnfQU5ZecPvyA3FE
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    enclosed-exceptions-1.0.3-IH7IgGKTEJFJLmctIAPJiT exceptions-0.10.7
    filepath-1.4.300.1 lifted-async-0.11.0-DvLFg7aKgzC77xUHNxZEMb
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    process-1.6.19.0 text-2.0.2 time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
